@@ -1,60 +1,55 @@
 """Validate Anything!"""
-# -*- coding: utf-8 -*-
-
-# isort: skip_file
-
-# The following imports are sorted alphabetically, manually.
-# Each line is grouped based first or type, then sorted alphabetically.
-# This is for the reference documentation.
 
 # local
 from .between import between
 from .btc_address import btc_address
 from .card import amex, card_number, diners, discover, jcb, mastercard, unionpay, visa
+from .country_code import country_code
 from .domain import domain
 from .email import email
 from .hashes import md5, sha1, sha224, sha256, sha512
 from .hostname import hostname
+from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn
 from .iban import iban
 from .ip_address import ipv4, ipv6
 from .length import length
 from .mac_address import mac_address
 from .slug import slug
 from .url import url
-from .utils import validator, ValidationFailure
+from .utils import ValidationError, validator
 from .uuid import uuid
 
-from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn
+# from .crypto_addresses import eth_address
 
 __all__ = (
-    "amex",
+    # ...
     "between",
+    # crypto addresses
     "btc_address",
+    # "eth_address",
+    # cards
+    "amex",
     "card_number",
     "diners",
     "discover",
-    "domain",
-    "email",
-    "hostname",
-    "iban",
-    "ipv4",
-    "ipv6",
     "jcb",
-    "length",
-    "mac_address",
     "mastercard",
+    "visa",
+    "unionpay",
+    # ...
+    "country_code",
+    # ...
+    "domain",
+    # ...
+    "email",
+    # hashes
     "md5",
     "sha1",
     "sha224",
     "sha256",
     "sha512",
-    "slug",
-    "unionpay",
-    "url",
-    "uuid",
-    "ValidationFailure",
-    "validator",
-    "visa",
+    # ...
+    "hostname",
     # i18n
     "es_cif",
     "es_doi",
@@ -62,6 +57,24 @@ __all__ = (
     "es_nif",
     "fi_business_id",
     "fi_ssn",
+    # ...
+    "iban",
+    # ip addresses
+    "ipv4",
+    "ipv6",
+    # ...
+    "length",
+    # ...
+    "mac_address",
+    # ...
+    "slug",
+    # ...
+    "url",
+    # ...
+    "uuid",
+    # utils
+    "ValidationError",
+    "validator",
 )
 
-__version__ = "0.20.0"
+__version__ = "0.21.2"
